==> nextcloud-app-spreed-1%3A8.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ko.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(시간 %s)",
    "You attended a call with {user1}" : "{user1} 님과의 통화에 참가함",
    "_%n guest_::_%n guests_" : ["손님 %n명"],
    "You attended a call with {user1} and {user2}" : "{user1}, {user2} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}, {user2}, {user3} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}, {user2}, {user3}, {user4} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}, {user2}, {user3}, {user4}, {user5} 님과의 통화에 참가함",
    "_%n other_::_%n others_" : ["외 %n명"],
    "{actor} invited you to {call}" : "{actor} 님이 {call}에 초대함",
    "Talk" : "토크",
    "Guest" : "손님",
    "Talk to %s" : "%s 님과 대화",
    "Join call" : "통화 참가하기",
    "{user} wants to talk with you" : "{user} 님이 여러분과 통화하려고 함",
    "A group call has started in {call}" : "그룹 통화가 {call}에 시작됨",
    "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다",
    "None" : "없음",
    "User" : "사용자",
    "Everyone" : "모두",
    "Disabled" : "비활성화됨",
    "Users" : "사용자",
    "Validate SSL certificate" : "SSL 인증서 확인",
    "TURN server protocols" : "TURN 서버 프로토콜",
    "UDP and TCP" : "UDP 및 TCP",
    "UDP only" : "UDP만",
    "TCP only" : "TCP만",
    "Copy link" : "링크 복사",
    "No other people in this call" : "이 통화에 다른 사람이 없음",
    "Waiting for others to join the call …" : "다른 사람을 기다리는 중 …",
    "You can invite others in the participant tab of the sidebar" : "사이드바의 참가자 탭에서 다른 사람들을 초대할 수 있음",
    "Share this link to invite others!" : "다른 사람을 초대하려면 링크를 공유하십시오!",
    "Show your screen" : "내 화면 보이기",
    "Stop screensharing" : "화면 공유 중지",
    "Screensharing options" : "화면 공유 옵션",
    "Enable screensharing" : "화면 공유 활성화",
    "Screensharing requires the page to be loaded through HTTPS." : "화면 공유를 사용하려면 HTTPS로 페이지를 불러 와야 합니다.",
    "Sharing your screen only works with Firefox version 52 or newer." : "화면 공유는 Firefox 버전 52 이상에서만 지원합니다.",
    "Screensharing extension is required to share your screen." : "화면 공유를 위한 확장 기능이 필요합니다.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "화면 공유를 사용하려면 Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오.",
    "An error occurred while starting screensharing." : "화면 공유를 시작하는 중 오류가 발생했습니다.",
    "Your screen" : "내 화면",
    "Show screen" : "화면 보이기",
    "Disable video" : "비디오 비활성화",
    "Enable video" : "비디오 활성화",
    "Favorite" : "즐겨찾기",
    "Leave conversation" : "대화 나가기",
    "Delete conversation" : "대화 삭제",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add to favorites" : "즐겨찾기에 추가",
    "Conversations" : "대화",
    "Contacts" : "연락처",
    "Groups" : "그룹",
    "Circles" : "서클",
    "Loading" : "불러오는 중",
    "Error" : "오류",
    "Password protect" : "암호 보호",
    "Back" : "뒤로",
    "Close" : "닫기",
    "Conversation name" : "대화명",
    "Reply" : "답장",
    "[Unknown user name]" : "[알 수 없는 사용자 이름]",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "moderator" : "중재자",
    "guest" : "손님",
    "Demote from moderator" : "중재자 권한 박탈",
    "Promote to moderator" : "중재자 권한 부여",
    "Remove participant" : "참가자 삭제",
    "No results" : "결과 없음",
    "Participants" : "참가자",
    "Rename conversation" : "대화 제목 변경",
    "Guests" : "손님",
    "Share link" : "링크 공유",
    "Password protection" : "암호 보호",
    "Enter a password" : "Enter a password",
    "Chat" : "대화",
    "Edit" : "편집",
    "Leave call" : "통화 떠나기",
    "Limit to groups" : "그룹으로 제한",
    "Save changes" : "변경 사항 저장",
    "Saving …" : "저장 중 …",
    "Saved!" : "저장했습니다!",
    "Beta" : "베타",
    "Name" : "이름",
    "General settings" : "일반 설정",
    "Saved" : "저장됨",
    "Shared secret" : "공유된 비밀 값",
    "STUN servers" : "STUN 서버",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN 서버는 라우터 뒤에 있는 참가자의 공인 IP 주소를 판단하는 데 사용합니다.",
    "Please enter the password for this call" : "이 통화의 암호를 입력하십시오",
    "Password required" : "암호가 필요함",
    "Password" : "암호",
    "Cancel" : "취소",
    "Submit" : "제출",
    "Access to microphone & camera is only possible with HTTPS" : "마이크와 카메라에는 HTTPS로만 접근할 수 있음",
    "Access to microphone & camera was denied" : "마이크 및 카메라 접근이 거부됨",
    "WebRTC is not supported in your browser" : "웹 브라우저에서 WebRTC를 지원하지 않음",
    "Please use a different browser like Firefox or Chrome" : "Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오",
    "Error while accessing microphone & camera" : "마이크와 카메라에 접근하는 중 오류 발생",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 시도하십시오",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "대규모 사용자가 필요한 경우 외부 신호 서버를 사용할 수 있습니다. 비워 두면 내장 신호 서버를 사용합니다.",
    "TURN server" : "TURN 서버",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN 서버는 방화벽 뒤에 있는 참가자의 트래픽을 중계합니다.",
    "Android app" : "Android 앱",
    "iOS app" : "iOS 앱",
    "Delete server" : "서버 삭제",
    "Add new server" : "새 서버 추가",
    "TURN server shared secret" : "TURN 서버 공유 비밀 키",
    "Copy" : "복사",
    "Copied!" : "복사 성공!",
    "Not supported!" : "지원하지 않음!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
    "Start a conversation" : "대화 시작",
    "Share" : "공유",
    "Change password" : "암호 변경",
    "Set password" : "암호 설정",
    "Rename" : "이름 바꾸기",
    "Conversation with {name}" : "{name} 님과 대화",
    "Link copied!" : "링크 복사됨!",
    "You" : "나",
    "No messages yet, start the conversation!" : "메시지가 없습니다. 대화를 시작하십시오!",
    "Send" : "보내기",
    "Error occurred while sending message" : "메시지를 보내는 중 오류 발생",
    "Error while sharing" : "공유하는 중 오류 발생",
    "Waiting for {participantName} to join the call …" : "{participantName} 님을 기다리는 중…",
    "WebRTC is not supported in your browser :-/" : "웹 브라우저에서 WebRTC를 지원하지 않습니다 :-/",
    "Waiting for camera and microphone permissions" : "카메라와 마이크 권한을 기다리는 중",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "이 앱을 사용하려면 웹 브라우저에 카메라 및 마이크 사용 권한을 부여해야 합니다.",
    "Mute audio" : "오디오 음소거",
    "Share screen" : "화면 공유",
    "No Camera" : "카메라 없음",
    "Screensharing is not supported by your browser." : "웹 브라우저에서 화면 공유를 지원하지 않습니다.",
    "Favorited" : "즐겨찾기에 추가됨",
    "Always notify" : "항상 알림",
    "Never notify" : "알림 끄기",
    "{participantName}'s screen" : "{participantName} 님의 화면",
    "Guest's screen" : "손님의 화면",
    "You were invited to a <strong>talk</strong> room or had a <strong>call</strong>" : "<strong>대화</strong>방에 초대받았거나 <strong>통화</strong>가 진행됨",
    "_%n other guest_::_%n other guests_" : ["다른 손님 %n명"],
    ", " : ",",
    "A group call has started" : "그룹 통화가 시작됨",
    "This call is password-protected" : "이 통화가 암호로 보호되어 있음",
    "Signaling server" : "신호 서버"
},
"nplurals=1; plural=0;");

==> nextcloud-app-spreed-1%3A8.0.9-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ko.js <==
OC.L10N.register(
    "spreed",
    {
    "(Duration %s)" : "(시간 %s)",
    "You attended a call with {user1}" : "{user1} 님과의 통화에 참가함",
    "_%n guest_::_%n guests_" : ["손님 %n명"],
    "You attended a call with {user1} and {user2}" : "{user1}, {user2} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2} and {user3}" : "{user1}, {user2}, {user3} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2}, {user3} and {user4}" : "{user1}, {user2}, {user3}, {user4} 님과의 통화에 참가함",
    "You attended a call with {user1}, {user2}, {user3}, {user4} and {user5}" : "{user1}, {user2}, {user3}, {user4}, {user5} 님과의 통화에 참가함",
    "_%n other_::_%n others_" : ["외 %n명"],
    "{actor} invited you to {call}" : "{actor} 님이 {call}에 초대함",
    "Talk" : "토크",
    "Guest" : "손님",
    "Talk to %s" : "%s 님과 대화",
    "Join call" : "통화 참가하기",
    "{user} wants to talk with you" : "{user} 님이 여러분과 통화하려고 함",
    "A group call has started in {call}" : "그룹 통화가 {call}에 시작됨",
    "Invalid date, date format must be YYYY-MM-DD" : "잘못된 날짜, YYYY-MM-DD 형식이어야 합니다",
    "Leave call" : "통화 떠나기",
    "Limit to groups" : "그룹으로 제한",
    "Everyone" : "모두",
    "Save changes" : "변경 사항 저장",
    "Saving …" : "저장 중 …",
    "Saved!" : "저장했습니다!",
    "None" : "없음",
    "User" : "사용자",
    "Disabled" : "비활성화됨",
    "Users" : "사용자",
    "Beta" : "베타",
    "Name" : "이름",
    "General settings" : "일반 설정",
    "Off" : "꺼짐",
    "Validate SSL certificate" : "SSL 인증서 확인",
    "Saved" : "저장됨",
    "Shared secret" : "공유된 비밀 값",
    "STUN servers" : "STUN 서버",
    "A STUN server is used to determine the public IP address of participants behind a router." : "STUN 서버는 라우터 뒤에 있는 참가자의 공인 IP 주소를 판단하는 데 사용합니다.",
    "TURN server protocols" : "TURN 서버 프로토콜",
    "UDP and TCP" : "UDP 및 TCP",
    "UDP only" : "UDP만",
    "TCP only" : "TCP만",
    "Copy link" : "링크 복사",
    "Waiting for others to join the call …" : "다른 사람을 기다리는 중 …",
    "You can invite others in the participant tab of the sidebar" : "사이드바의 참가자 탭에서 다른 사람들을 초대할 수 있음",
    "Share this link to invite others!" : "다른 사람을 초대하려면 링크를 공유하십시오!",
    "Show your screen" : "내 화면 보이기",
    "Stop screensharing" : "화면 공유 중지",
    "Mute audio" : "오디오 음소거",
    "Disable video" : "비디오 비활성화",
    "Enable video" : "비디오 활성화",
    "Screensharing options" : "화면 공유 옵션",
    "Enable screensharing" : "화면 공유 활성화",
    "Screensharing requires the page to be loaded through HTTPS." : "화면 공유를 사용하려면 HTTPS로 페이지를 불러 와야 합니다.",
    "Sharing your screen only works with Firefox version 52 or newer." : "화면 공유는 Firefox 버전 52 이상에서만 지원합니다.",
    "Screensharing extension is required to share your screen." : "화면 공유를 위한 확장 기능이 필요합니다.",
    "Please use a different browser like Firefox or Chrome to share your screen." : "화면 공유를 사용하려면 Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오.",
    "An error occurred while starting screensharing." : "화면 공유를 시작하는 중 오류가 발생했습니다.",
    "Your screen" : "내 화면",
    "Show screen" : "화면 보이기",
    "Favorite" : "즐겨찾기",
    "Leave conversation" : "대화 나가기",
    "Delete conversation" : "대화 삭제",
    "Remove from favorites" : "즐겨찾기에서 제거",
    "Add to favorites" : "즐겨찾기에 추가",
    "Conversations" : "대화",
    "Contacts" : "연락처",
    "Loading" : "불러오는 중",
    "Groups" : "그룹",
    "Circles" : "서클",
    "Error" : "오류",
    "Password protect" : "암호 보호",
    "Back" : "뒤로",
    "Close" : "닫기",
    "Conversation name" : "대화명",
    "Reply" : "답장",
    "Today" : "오늘",
    "Yesterday" : "어제",
    "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
    "Send message" : "메시지 보내기",
    "moderator" : "중재자",
    "guest" : "손님",
    "Demote from moderator" : "중재자 권한 박탈",
    "Promote to moderator" : "중재자 권한 부여",
    "Remove participant" : "참가자 삭제",
    "No results" : "결과 없음",
    "Participants" : "참가자",
    "Chat" : "대화",
    "Settings" : "설정",
    "Edit" : "편집",
    "Dismiss" : "무시",
    "Rename conversation" : "대화 제목 변경",
    "Share link" : "링크 공유",
    "Password protection" : "암호 보호",
    "Enter a password" : "Enter a password",
    "Grid view" : "바둑판식 보기",
    "Access to microphone & camera is only possible with HTTPS" : "마이크와 카메라에는 HTTPS로만 접근할 수 있음",
    "Access to microphone & camera was denied" : "마이크 및 카메라 접근이 거부됨",
    "WebRTC is not supported in your browser" : "웹 브라우저에서 WebRTC를 지원하지 않음",
    "Please use a different browser like Firefox or Chrome" : "Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오",
    "Error while accessing microphone & camera" : "마이크와 카메라에 접근하는 중 오류 발생",
    "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 시도하십시오",
    "Password" : "암호",
    "TURN server" : "TURN 서버",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN 서버는 방화벽 뒤에 있는 참가자의 트래픽을 중계합니다.",
    "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "대규모 사용자가 필요한 경우 외부 신호 서버를 사용할 수 있습니다. 비워 두면 내장 신호 서버를 사용합니다.",
    "Android app" : "Android 앱",
    "iOS app" : "iOS 앱",
    "Copy" : "복사",
    "Copied!" : "복사 성공!",
    "Not supported!" : "지원하지 않음!",
    "Press ⌘-C to copy." : "복사하려면 ⌘-C 키를 누르십시오.",
    "Press Ctrl-C to copy." : "복사하려면 Ctrl-C 키를 누르십시오.",
    "Please enter the password for this call" : "이 통화의 암호를 입력하십시오",
    "Password required" : "암호가 필요함",
    "Cancel" : "취소",
    "Submit" : "제출",
    "Guests" : "손님",
    "Change password" : "암호 변경",
    "Set password" : "암호 설정",
    "Rename" : "이름 바꾸기",
    "Link copied!" : "링크 복사됨!",
    "Conversation with {name}" : "{name} 님과 대화",
    "You" : "나",
    "No messages yet, start the conversation!" : "메시지가 없습니다. 대화를 시작하십시오!",
    "Send" : "보내기",
    "Share" : "공유",
    "[Unknown user name]" : "[알 수 없는 사용자 이름]",
    "Error occurred while sending message" : "메시지를 보내는 중 오류 발생",
    "Error while sharing" : "공유하는 중 오류 발생",
    "No other people in this call" : "이 통화에 다른 사람이 없음",
    "Waiting for {participantName} to join the call …" : "{participantName} 님을 기다리는 중…",
    "WebRTC is not supported in your browser :-/" : "웹 브라우저에서 WebRTC를 지원하지 않습니다 :-/",
    "Waiting for camera and microphone permissions" : "카메라와 마이크 권한을 기다리는 중",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "이 앱을 사용하려면 웹 브라우저에 카메라 및 마이크 사용 권한을 부여해야 합니다.",
    "Share screen" : "화면 공유",
    "No Camera" : "카메라 없음",
    "Screensharing is not supported by your browser." : "웹 브라우저에서 화면 공유를 지원하지 않습니다.",
    "Favorited" : "즐겨찾기에 추가됨",
    "{participantName}'s screen" : "{participantName} 님의 화면",
    "Guest's screen" : "손님의 화면"
},
"nplurals=1; plural=0;");
